# py_extract
Py_extract is a simple, light-weight python library to handle some extraction tasks using less lines of code.
**Still in Development Stage!**

## Installation
```
pip install git+https://github.com/Itz-fork/py-extract.git
```

# Features,
- Get Video metadata (data will returns as json)
- Extract Audio from a video

Only This for now, more features coming soon 😉...

# Docs
You can find the official docs and code snippets [here](https://pyextract.netlify.app/)

# License
[py_extract](https://github.com/Itz-fork/py-extract) is licensed under MIT License

Copyright ©️ 2021 - [Itz-fork](https://github.com/Itz-fork)